# Jpp

The following source files were taken from Jpp version v17.0.0-rc.1-172-g2b9d6e0cb
and are used for testing and as fallback if no Jpp environment is loaded.

See https://git.km3net.de/common/jpp
